pub fn render_help(spec: &CommandSpec) -> StringExpand description
Render --help text for a command spec, formatted comparably to clap:
about, usage, aliases, commands, arguments, options (with an auto
-h, --help), and any after_help.
pub fn render_help(spec: &CommandSpec) -> StringRender --help text for a command spec, formatted comparably to clap:
about, usage, aliases, commands, arguments, options (with an auto
-h, --help), and any after_help.